@@ -197,8 +197,8 @@ It allows you to install Arch Linux or perform system maintenance.
 ENDTEXT
 MENU LABEL Boot Arch Linux (x86_64)
 LINUX /boot/vmlinuz_x86_64
-APPEND cgroup_disable=memory loglevel=7 rootdelay=10
-INITRD /boot/initramfs_x86_64.img
+APPEND cgroup_disable=memory rootdelay=10
+INITRD /boot/intel-ucode.img,/boot/initramfs_x86_64.img
 
 EOF
 	fi
@@ -213,8 +213,8 @@ It allows you to install Arch Linux or perform system maintenance.
 ENDTEXT
 MENU LABEL Boot Arch Linux (i686)
 LINUX /boot/vmlinuz_i686
-APPEND cgroup_disable=memory loglevel=7 rootdelay=10
-INITRD /boot/initramfs_i686.img
+APPEND cgroup_disable=memory rootdelay=10
+INITRD /boot/intel-ucode.img,/boot/initramfs_i686.img
 
 EOF
 	fi
@@ -339,16 +339,18 @@ GUMEOF
 	cat << GUMEOF > "${_ARCHBOOT_ISO_EXT_DIR}/loader/entries/archboot-x86_64-efistub.conf"
 title           Arch Linux x86_64 Archboot EFISTUB
 linux           /boot/vmlinuz_x86_64
+initrd          /boot/intel-ucode.img
 initrd          /boot/initramfs_x86_64.img
-options         cgroup_disable=memory loglevel=7 add_efi_memmap _X64_UEFI=1
+options         cgroup_disable=memory add_efi_memmap _X64_UEFI=1
 architecture    x64
 GUMEOF
 	
 	# cat << GUMEOF > "${_ARCHBOOT_ISO_EXT_DIR}/loader/entries/archboot-i686-efistub.conf"
 # title           Arch Linux i686 Archboot EFISTUB
 # linux           /boot/vmlinuz_i686
+# initrd          /boot/intel-ucode.img
 # initrd          /boot/initramfs_i686.img
-# options         cgroup_disable=memory loglevel=7 add_efi_memmap _IA32_UEFI=1
+# options         cgroup_disable=memory add_efi_memmap _IA32_UEFI=1
 # architecture    ia32
 # GUMEOF
 	
@@ -428,8 +430,8 @@ set timeout="2"
 menuentry "Arch Linux x86_64 Archboot Non-EFISTUB" {
     set gfxpayload=keep
     search --no-floppy --set=root --file /boot/vmlinuz_x86_64
-    linux /boot/vmlinuz_x86_64 cgroup_disable=memory loglevel=7 add_efi_memmap _X64_UEFI=1
-    initrd /boot/initramfs_x86_64.img
+    linux /boot/vmlinuz_x86_64 cgroup_disable=memory add_efi_memmap _X64_UEFI=1
+    initrd /boot/intel-ucode.img /boot/initramfs_x86_64.img
 }
 
 menuentry "UEFI Shell X64 v2" {
@@ -484,15 +486,15 @@ set timeout="2"
 menuentry "Arch Linux x86_64 Archboot - EFI MIXED MODE" {
     set gfxpayload=keep
     search --no-floppy --set=root --file /boot/vmlinuz_x86_64
-    linux /boot/vmlinuz_x86_64 cgroup_disable=memory loglevel=7 add_efi_memmap _IA32_UEFI=1
-    initrd /boot/initramfs_x86_64.img
+    linux /boot/vmlinuz_x86_64 cgroup_disable=memory add_efi_memmap _IA32_UEFI=1
+    initrd /boot/intel-ucode.img /boot/initramfs_x86_64.img
 }
 
 menuentry "Arch Linux i686 Archboot Non-EFISTUB" {
     set gfxpayload=keep
     search --no-floppy --set=root --file /boot/vmlinuz_i686
-    linux /boot/vmlinuz_i686 cgroup_disable=memory loglevel=7 add_efi_memmap _IA32_UEFI=1
-    initrd /boot/initramfs_i686.img
+    linux /boot/vmlinuz_i686 cgroup_disable=memory add_efi_memmap _IA32_UEFI=1
+    initrd /boot/intel-ucode.img /boot/initramfs_i686.img
 }
 
 # menuentry "Syslinux for x86_64 Kernel in IA32 UEFI" {
@@ -541,14 +543,14 @@ MENU RESOLUTION 1280 800
 LABEL archboot-x86_64
     MENU LABEL Arch Linux x86_64 Archboot - EFI MIXED MODE
     LINUX /boot/vmlinuz_x86_64
-    APPEND cgroup_disable=memory loglevel=7 add_efi_memmap _IA32_UEFI=1
-    INITRD /boot/initramfs_x86_64.img
+    APPEND cgroup_disable=memory add_efi_memmap _IA32_UEFI=1
+    INITRD /boot/intel-ucode.img,/boot/initramfs_x86_64.img
 
 LABEL archboot-i686
     MENU LABEL Arch Linux i686 Archboot - EFI HANDOVER PROTOCOL
     LINUX /boot/vmlinuz_i686
-    APPEND cgroup_disable=memory loglevel=7 add_efi_memmap _IA32_UEFI=1
-    INITRD /boot/initramfs_i686.img
+    APPEND cgroup_disable=memory add_efi_memmap _IA32_UEFI=1
+    INITRD /boot/intel-ucode.img,/boot/initramfs_i686.img
 EOF
 	
 }
